@@ -1,28 +1,41 @@
+import importlib
 import subprocess
 import sys
+from types import ModuleType
 
+import pytest
 from typer.testing import CliRunner
 
-from docs_src.options.help import tutorial002 as mod
-
 runner = CliRunner()
-app = mod.app
 
 
-def test_call():
-    result = runner.invoke(app, ["World"])
+@pytest.fixture(
+    name="mod",
+    params=[
+        pytest.param("tutorial002_py39"),
+        pytest.param("tutorial002_an_py39"),
+    ],
+)
+def get_mod(request: pytest.FixtureRequest) -> ModuleType:
+    module_name = f"docs_src.options.help.{request.param}"
+    mod = importlib.import_module(module_name)
+    return mod
+
+
+def test_call(mod: ModuleType):
+    result = runner.invoke(mod.app, ["World"])
     assert result.exit_code == 0
     assert "Hello World" in result.output
 
 
-def test_formal():
-    result = runner.invoke(app, ["World", "--formal"])
+def test_formal(mod: ModuleType):
+    result = runner.invoke(mod.app, ["World", "--formal"])
     assert result.exit_code == 0
     assert "Good day Ms. World" in result.output
 
 
-def test_help():
-    result = runner.invoke(app, ["--help"])
+def test_help(mod: ModuleType):
+    result = runner.invoke(mod.app, ["--help"])
     assert result.exit_code == 0
     assert "--lastname" in result.output
     assert "Customization and Utils" in result.output
@@ -32,7 +45,7 @@ def test_help():
     assert "--no-debug" in result.output
 
 
-def test_script():
+def test_script(mod: ModuleType):
     result = subprocess.run(
         [sys.executable, "-m", "coverage", "run", mod.__file__, "--help"],
         capture_output=True,
